@@ -1,5 +1,5 @@
 from eloquentarduino.jupyter.EloquentArduinoMagics import EloquentSketchMagics
-from eloquentarduino.jupyter.project import project
+from eloquentarduino.jupyter.project import Project, project
 
 
 def load_ipython_extension(ipython):
