@@ -1,2 +1,2 @@
-from eloquentarduino.jupyter.project.Project import project
-from eloquentarduino.jupyter.project.BoardConfiguration import BoardConfiguration
\ No newline at end of file
+from eloquentarduino.jupyter.project.Project import Project, project
+from eloquentarduino.jupyter.project.BoardConfiguration import BoardConfiguration
