@@ -2,7 +2,7 @@ class GridSearchResult:
     """
     Result of a grid search iteration
     """
-    def __init__(self, dataset, clf, accuracy, resources, inference_time):
+    def __init__(self, dataset, clf, accuracy, resources=None, inference_time=None):
         """
         
         """
@@ -10,4 +10,4 @@ class GridSearchResult:
         self.clf = clf
         self.accuracy = accuracy
         self.resources = resources
-        self.inference_time = inference_time
\ No newline at end of file
+        self.inference_time = inference_time
