@@ -6,4 +6,7 @@ class GaussianNB(SklearnClassifier, SklearnImplementation):
     """
     sklearn.naive_bayes.GaussianNB wrapper
     """
-    pass
\ No newline at end of file
+    def hyperparameters_grid(self, X=None):
+        return {
+            'var_smoothing': [1e-5, 1e-7, 1e-9]
+        }
\ No newline at end of file
