@@ -23,7 +23,7 @@ class RollingWindow:
         assert num_windows > 0, "num_windows MUST be greater than 0"
         assert axis > 0, "axis MUST be greather than 0"
         assert len(X) == len(y), "X and y MUST have the same length"
-        assert len(y) > 1, "y MUST be of at least 2 elements"
+        # assert len(y) > 1, "y MUST be of at least 2 elements"
         assert features is None or isinstance(features, list) or isinstance(features, tuple), \
             'features MUST be None or a list'
 
@@ -50,7 +50,7 @@ class RollingWindow:
         if self.has(RollingWindow.STD):
             self.features.add(RollingWindow.MEAN)
 
-        self.Xt, self.yt = self.transform(X, y)
+        self.Xt, self.Xw, self.yt = self.transform(X, y)
 
     def has(self, feature):
         """
@@ -63,9 +63,9 @@ class RollingWindow:
         Transform data
         """
         assert len(X) == len(y), "X and y MUST have the same length"
-        assert len(y) > 1, "y MUST be of at least 2 elements"
+        #assert len(y) > 1, "y MUST be of at least 2 elements"
 
-        Xt, yt = None, None
+        Xt, yt, Xw = None, None, None
 
         for xi, yi in zip(X, y):
             # algorithm:
@@ -86,16 +86,18 @@ class RollingWindow:
             if Xt is None:
                 Xt = Xi
                 yt = yi
+                Xw = windows
             else:
                 Xt = np.vstack((Xt, Xi))
+                Xw = np.vstack((Xw, windows))
                 yt = np.concatenate((yt, yi))
 
-        return np.nan_to_num(Xt), yt
+        return np.nan_to_num(Xt), Xw, yt
 
     def port(self):
         """
         Port to plain C++
-        :return: plain C++ code
+        :return: str plain C++ code
         """
         env = {
             'num_windows': self.num_windows,
